@@ -17,7 +17,8 @@ NULL
 if(getRversion() >= "2.15.1")  utils::globalVariables(c('brazil_2010',
                                                         'grid_state_correspondence_table',
                                                         'data',
-                                                        "geo",
+                                                        'geo',
+                                                        'con',
                                                         'code',
                                                         'code_weighting_area',
                                                         'code_muni',
