@@ -22,9 +22,7 @@ test_that("read_region", {
   # check number of rows
   expect_equal(nrow(test_sf), 5)
 
-  # check projection
-  expect_equal(sf::st_crs(test_sf)$proj4string, "+proj=longlat +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +no_defs ")
-})
+  })
 
 
 
